pub struct PairedRunRequest {Show 18 fields
pub name: String,
pub cwd: Option<PathBuf>,
pub baseline_command: Vec<String>,
pub current_command: Vec<String>,
pub repeat: u32,
pub warmup: u32,
pub work_units: Option<u64>,
pub timeout: Option<Duration>,
pub env: Vec<(String, String)>,
pub output_cap_bytes: usize,
pub allow_nonzero: bool,
pub include_hostname_hash: bool,
pub significance_alpha: Option<f64>,
pub significance_min_samples: Option<u32>,
pub require_significance: bool,
pub max_retries: u32,
pub fail_on_regression: Option<f64>,
pub cv_threshold: Option<f64>,
}Fields
name: Stringcwd: Option<PathBuf>baseline_command: Vec<String>current_command: Vec<String>repeat: u32warmup: u32work_units: Option<u64>timeout: Option<Duration>env: Vec<(String, String)>output_cap_bytes: usizeallow_nonzero: boolinclude_hostname_hash: boolsignificance_alpha: Option<f64>significance_min_samples: Option<u32>require_significance: boolmax_retries: u32fail_on_regression: Option<f64>cv_threshold: Option<f64>CV threshold for early termination. If the coefficient of variation of the wall-time differences exceeds this value, retries are aborted because the benchmark is too noisy for significance to be achievable.