pub struct PromoteUseCase;Expand description
Use case for promoting run receipts to baselines.
Implementations
Sourceimpl PromoteUseCase
impl PromoteUseCase
Sourcepub fn execute(req: PromoteRequest) -> PromoteResult
pub fn execute(req: PromoteRequest) -> PromoteResult
Execute the promote operation.
If normalize is true, the receipt will have run-specific fields
(run_id, started_at, ended_at) replaced with placeholder values
to make the baseline more stable for comparison purposes.