pub struct RunBenchRequest {
pub name: String,
pub cwd: Option<PathBuf>,
pub command: Vec<String>,
pub repeat: u32,
pub warmup: u32,
pub work_units: Option<u64>,
pub timeout: Option<Duration>,
pub env: Vec<(String, String)>,
pub output_cap_bytes: usize,
pub allow_nonzero: bool,
pub include_hostname_hash: bool,
}Fields
name: Stringcwd: Option<PathBuf>command: Vec<String>repeat: u32warmup: u32work_units: Option<u64>timeout: Option<Duration>env: Vec<(String, String)>output_cap_bytes: usizeallow_nonzero: boolIf true, do not treat nonzero exit codes as a tool error. The receipt will still record exit codes.
include_hostname_hash: boolIf true, include a hashed hostname in the host fingerprint. This is opt-in for privacy reasons.